ios\_build package
==================

.. include:: ../ios_build/README.md
   :parser: myst_parser.sphinx_

Submodules
----------

ios\_build.build module
-----------------------

.. automodule:: ios_build.build
   :members:
   :undoc-members:
   :show-inheritance:

ios\_build.cmake module
-----------------------

.. automodule:: ios_build.cmake
   :members:
   :undoc-members:
   :show-inheritance:

ios\_build.interface module
---------------------------

.. automodule:: ios_build.interface
   :members:
   :undoc-members:
   :show-inheritance:

ios\_build.parser module
------------------------

.. automodule:: ios_build.parser
   :members:
   :undoc-members:
   :show-inheritance:

ios\_build.printer module
-------------------------

.. automodule:: ios_build.printer
   :members:
   :undoc-members:
   :show-inheritance:

ios\_build.run module
---------------------

.. automodule:: ios_build.run
   :members:
   :undoc-members:
   :show-inheritance:

ios\_build.search module
------------------------

.. automodule:: ios_build.search
   :members:
   :undoc-members:
   :show-inheritance:

ios\_build.xcodebuild module
----------------------------

.. automodule:: ios_build.xcodebuild
   :members:
   :undoc-members:
   :show-inheritance:
